==> gdbgui-0.14.0.0.tar.gz: gdbgui-0.14.0.0/gdbgui/src/js/GlobalEvents.ts <==
/**
 * Setup global DOM events
 */

import constants from "./constants";
import GdbApi from "./GdbApi";

const GlobalEvents = {
  init: function() {
    window.onkeydown = function(e: any) {
      if (e.keyCode === constants.ENTER_BUTTON_NUM) {
        // when pressing enter in an input, don't redirect entire page!
        e.preventDefault();
      }
    };
    $("body").on("keydown", GlobalEvents.body_keydown);
    // @ts-expect-error ts-migrate(2339) FIXME: Property 'tooltip' does not exist on type 'JQuery<... Remove this comment to see the full error message
    $("[data-toggle=\"tooltip\"]").tooltip();

    window.onbeforeunload = () =>
      "text here makes dialog appear when exiting. Set function to back to null for nomal behavior.";
  },
  /**
   * keyboard shortcuts to interact with gdb.
   * enabled only when key is depressed on a target that is NOT an input.
   */
  body_keydown: function(e: any) {
    let modifier = e.altKey || e.ctrlKey || e.metaKey;

    if (e.target.nodeName !== "INPUT" && !modifier) {
      let char = String.fromCharCode(e.keyCode).toLowerCase();
      if (e.keyCode === constants.DOWN_BUTTON_NUM || char === "s") {
        GdbApi.click_step_button();
      } else if (e.keyCode === constants.RIGHT_BUTTON_NUM) {
        GdbApi.click_next_button();
      } else if (char === "n") {
        GdbApi.click_next_button(e.shiftKey);
      } else if (char === "c") {
        GdbApi.click_continue_button(e.shiftKey);
      } else if (e.keyCode === constants.UP_BUTTON_NUM || char === "u") {
        GdbApi.click_return_button();
      } else if (char === "r") {
        GdbApi.click_run_button();
      } else if (char === "m") {
        GdbApi.click_next_instruction_button(e.shiftKey);
      } else if (e.keyCode === constants.COMMA_BUTTON_NUM) {
        GdbApi.click_step_instruction_button(e.shiftKey);
        // @ts-expect-error ts-migrate(2304) FIXME: Cannot find name 'initial_data'.
      } else if (initial_data.rr && e.keyCode === constants.LEFT_BUTTON_NUM) {
        // reverse
        GdbApi.click_next_button(true);
      }
    }
  }
};

export default GlobalEvents;

==> gdbgui-0.14.0.2.tar.gz: gdbgui-0.14.0.2/gdbgui/src/js/GlobalEvents.ts <==
/**
 * Setup global DOM events
 */

import constants from "./constants";
import GdbApi from "./GdbApi";
import { store } from "statorgfc";

const GlobalEvents = {
  init: function() {
    window.onkeydown = function(e: any) {
      if (e.keyCode === constants.ENTER_BUTTON_NUM) {
        // when pressing enter in an input, don't redirect entire page!
        e.preventDefault();
      }
    };
    $("body").on("keydown", GlobalEvents.body_keydown);
    // @ts-expect-error ts-migrate(2339) FIXME: Property 'tooltip' does not exist on type 'JQuery<... Remove this comment to see the full error message
    $('[data-toggle="tooltip"]').tooltip();

    window.onbeforeunload = () =>
      "text here makes dialog appear when exiting. Set function to back to null for nomal behavior.";
  },
  /**
   * keyboard shortcuts to interact with gdb.
   * enabled only when key is depressed on a target that is NOT an input.
   */
  body_keydown: function(e: any) {
    let modifier = e.altKey || e.ctrlKey || e.metaKey;

    if (e.target.nodeName !== "INPUT" && !modifier) {
      let char = String.fromCharCode(e.keyCode).toLowerCase();
      if (e.keyCode === constants.DOWN_BUTTON_NUM || char === "s") {
        GdbApi.click_step_button();
      } else if (e.keyCode === constants.RIGHT_BUTTON_NUM) {
        GdbApi.click_next_button();
      } else if (char === "n") {
        GdbApi.click_next_button(e.shiftKey);
      } else if (char === "c") {
        GdbApi.click_continue_button(e.shiftKey);
      } else if (e.keyCode === constants.UP_BUTTON_NUM || char === "u") {
        GdbApi.click_return_button();
      } else if (char === "r") {
        GdbApi.click_run_button();
      } else if (char === "m") {
        GdbApi.click_next_instruction_button(e.shiftKey);
      } else if (e.keyCode === constants.COMMA_BUTTON_NUM) {
        GdbApi.click_step_instruction_button(e.shiftKey);
      } else if (
        e.keyCode === constants.LEFT_BUTTON_NUM &&
        store.get("reverse_supported")
      ) {
        GdbApi.click_next_button(true);
      }
    }
  }
};

export default GlobalEvents;
